==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ALLSPECIFIC" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}GENERATECOUNT"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BYLOT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARENTEQUIPMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPENDENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentconfigurationid",
    "equipmentconfigstatus",
    "allspecific",
    "departmentid",
    "commissiondate",
    "equipmentstatus",
    "locationid",
    "costcodeid",
    "assignedto",
    "storeid",
    "bin",
    "lotid",
    "generatecount",
    "objtype",
    "partid",
    "bylot",
    "parentequipmentid",
    "dependent",
    "costrollup"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "ALLSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String allspecific;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "COMMISSIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME commissiondate;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOTID_Type lotid;
    @XmlElement(name = "GENERATECOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY generatecount;
    @XmlElement(name = "OBJTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String objtype;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bylot;
    @XmlElement(name = "PARENTEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type parentequipmentid;
    @XmlElement(name = "DEPENDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String dependent;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costrollup;

    /**
     * Gets the value of the equipmentconfigurationid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Sets the value of the equipmentconfigurationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Gets the value of the equipmentconfigstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Sets the value of the equipmentconfigstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Gets the value of the allspecific property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLSPECIFIC() {
        return allspecific;
    }

    /**
     * Sets the value of the allspecific property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLSPECIFIC(String value) {
        this.allspecific = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the commissiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMMISSIONDATE() {
        return commissiondate;
    }

    /**
     * Sets the value of the commissiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMMISSIONDATE(DATETIME value) {
        this.commissiondate = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the costcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Sets the value of the costcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the generatecount property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getGENERATECOUNT() {
        return generatecount;
    }

    /**
     * Sets the value of the generatecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setGENERATECOUNT(QUANTITY value) {
        this.generatecount = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the bylot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Sets the value of the bylot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

    /**
     * Gets the value of the parentequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPARENTEQUIPMENTID() {
        return parentequipmentid;
    }

    /**
     * Sets the value of the parentequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPARENTEQUIPMENTID(EQUIPMENTID_Type value) {
        this.parentequipmentid = value;
    }

    /**
     * Gets the value of the dependent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENT() {
        return dependent;
    }

    /**
     * Sets the value of the dependent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENT(String value) {
        this.dependent = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GENERATECOUNT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYLOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTEQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentconfigurationid",
    "equipmentconfigstatus",
    "allspecific",
    "departmentid",
    "commissiondate",
    "equipmentstatus",
    "locationid",
    "costcodeid",
    "assignedto",
    "storeid",
    "bin",
    "lotid",
    "generatecount",
    "objtype",
    "partid",
    "bylot",
    "parentequipmentid",
    "dependent",
    "costrollup"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "ALLSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String allspecific;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "COMMISSIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME commissiondate;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOTID_Type lotid;
    @XmlElement(name = "GENERATECOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY generatecount;
    @XmlElement(name = "OBJTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String objtype;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bylot;
    @XmlElement(name = "PARENTEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type parentequipmentid;
    @XmlElement(name = "DEPENDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String dependent;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costrollup;

    /**
     * Gets the value of the equipmentconfigurationid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Sets the value of the equipmentconfigurationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Gets the value of the equipmentconfigstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Sets the value of the equipmentconfigstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Gets the value of the allspecific property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLSPECIFIC() {
        return allspecific;
    }

    /**
     * Sets the value of the allspecific property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLSPECIFIC(String value) {
        this.allspecific = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the commissiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMMISSIONDATE() {
        return commissiondate;
    }

    /**
     * Sets the value of the commissiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMMISSIONDATE(DATETIME value) {
        this.commissiondate = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the costcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Sets the value of the costcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the generatecount property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getGENERATECOUNT() {
        return generatecount;
    }

    /**
     * Sets the value of the generatecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setGENERATECOUNT(QUANTITY value) {
        this.generatecount = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the bylot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Sets the value of the bylot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

    /**
     * Gets the value of the parentequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPARENTEQUIPMENTID() {
        return parentequipmentid;
    }

    /**
     * Sets the value of the parentequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPARENTEQUIPMENTID(EQUIPMENTID_Type value) {
        this.parentequipmentid = value;
    }

    /**
     * Gets the value of the dependent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENT() {
        return dependent;
    }

    /**
     * Sets the value of the dependent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENT(String value) {
        this.dependent = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

}
